from leab import after
from leab import leDataset


def test_get_size_absolute():
    data = leDataset.SampleLeAverage()
    ab_test = after.leAverage(data.A, data.B)
    assert ab_test.sample_A.confidence_interval == [
        34.75214007684581,
        81.59785992315418,
    ]


def test_get_size_absolute():
    data = leDataset.SampleLeAverage()
    ab_test = after.leAverage(data.A, data.B)
    assert ab_test.get_verdict() == "Sample A mean is greater"



from leab import before


def test_get_size_per_variation_absolute():
    ab_test = before.leSample(conversion_rate=20, min_detectable_effect=2)
    assert ab_test.get_size_per_variation() == 6347


def test_get_size_per_variation_relative():
    ab_test = before.leSample(
        conversion_rate=20, min_detectable_effect=2, absolute=False
    )
    assert ab_test.get_size_per_variation() == 157328


def test_get_total_size_absolute():
    ab_test = before.leSample(conversion_rate=20, min_detectable_effect=2)
    assert ab_test.get_total_size() == 12694


def test_get_total_size_relative():
    ab_test = before.leSample(
        conversion_rate=20, min_detectable_effect=2, absolute=False
    )
    assert ab_test.get_total_size() == 314656


def test_get_duration_absolute():
    ab_test = before.leSample(conversion_rate=20, min_detectable_effect=2)
    assert ab_test.get_duration(avg_daily_total_visitor=1000) == 13


def test_get_duration_relative():
    ab_test = before.leSample(
        conversion_rate=20, min_detectable_effect=2, absolute=False
    )
    assert ab_test.get_duration(avg_daily_total_visitor=1000) == 315



from leab import after
from leab import leDataset


def test_get_confidence_interval():
    data = leDataset.SampleLeSuccess()
    ab_test = after.leSuccess(data.A, data.B, confidence_level=0.95)
    assert ab_test.sample_A.confidence_interval == [
        8.526343659939133,
        22.13718821096384,
    ]


def test_get_p_value():
    data = leDataset.SampleLeSuccess()
    ab_test = after.leSuccess(data.A, data.B, confidence_level=0.95)
    assert ab_test.p_value == 0.25870176105718934


def test_get_verdict():
    data = leDataset.SampleLeSuccess()
    ab_test = after.leSuccess(data.A, data.B, confidence_level=0.95)
    assert ab_test.get_verdict() == "No significant difference"
